package
Version:
v0.9.0
Opens a new window with list of versions in this module.
Published: Aug 5, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Provider struct {
Key string
}
Provider reads instance identity from an environment variable.
InstanceID returns the env value or empty string.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.