package
Version:
v0.9.0
Opens a new window with list of versions in this module.
Published: Aug 5, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Provider struct {
EnvKey string
}
Provider returns Kubernetes pod name as instance identity.
InstanceID prefers POD_NAME, then HOSTNAME, else "unknown".
Source Files
¶
Click to show internal directories.
Click to hide internal directories.