httpserver

package
v0.10.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 11, 2026 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Overview

Package httpserver integrates ShiftLock ownership with HTTP leadership gates.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RequireOwnership

func RequireOwnership(coord *shiftlock.Coordinator, claim string) func(http.Handler) http.Handler

RequireOwnership returns middleware that rejects requests unless the claim is owned by this generation with a live lease.

Types

This section is empty.

Jump to